
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.18.3',
    'branch_nick': 'patch-0-Rucio_1_18_3_preparation',
    'revision_id': 'ead0b352a0e16c72dd4096b0a8d6bd9a02c18668',
    'revno': 7180
}
